import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';
import { menu } from './menu';
import { getData, options } from './getData';



const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const menuContainer = select('body')
  .append('div')
  .attr('class', 'menu-container');

const xMenu = menuContainer.append('div');
const yMenu = menuContainer.append('div');

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await getData)
    .xTitle('X')
    .yTitle('Y')
    .xValue((d) => d.petal_width)
    .yValue((d) => d.petal_width)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  svg.call(plot);


  xMenu.call(
    menu()
      .id('x-menu')
      .labelText('X:')
      .options(options)
      .on('change', (column) => {
        svg.call(plot.xValue((d) => d[column]));
      })
  );
  yMenu.call(
    menu()
      .id('y-menu')
      .labelText('Y:')
      .options(options)
      .on('change', (column) => {
        svg.call(plot.yValue((d) => d[column]));
      })
  );
};
main();
